<?php

namespace Drupal\domain_simple_sitemap\Controller;

use Drupal\domain\DomainNegotiatorInterface;
use Drupal\simple_sitemap\Controller\SimplesitemapController;
use Drupal\simple_sitemap\Simplesitemap;
use Drupal\simple_sitemap\SimplesitemapManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class DomainSimpleSitemapController.
 *
 * @package Drupal\simple_sitemap\Controller
 */
class DomainSimpleSitemapController extends SimplesitemapController {

  /**
   * Drupal `simple_sitemap.generator` service.
   *
   * @var \Drupal\simple_sitemap\Simplesitemap
   */
  protected $generator;

  /**
   * Drupal `domain.negotiator` service.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  /**
   * Drupal `simple_sitemap.manager` service.
   *
   * @var \Drupal\simple_sitemap\SimplesitemapManager
   */
  protected $sitemapManager;

  /**
   * DomainSitemapController constructor.
   *
   * @param \Drupal\simple_sitemap\Simplesitemap $generator
   *   Drupal `simple_sitemap.generator` service.
   * @param \Drupal\domain\DomainNegotiatorInterface $domain_negoriator
   *   Drupal `domain.negotiator` service.
   * @param \Drupal\simple_sitemap\SimplesitemapManager $sitemap_manager
   *   Drupal `simple_sitemap.manager` service.
   */
  public function __construct(Simplesitemap $generator, DomainNegotiatorInterface $domain_negoriator, SimplesitemapManager $sitemap_manager) {
    $this->generator = $generator;
    $this->domainNegotiator = $domain_negoriator;
    $this->sitemapManager = $sitemap_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('simple_sitemap.generator'),
      $container->get('domain.negotiator'),
      $container->get('simple_sitemap.manager')
    );
  }

  /**
   * If variant NULL, default to the domain matching variant.
   *
   * {@inheritdoc}
   */
  public function getSitemap(Request $request, $variant = NULL) {
    if (empty($variant)) {
      $active_domain = $this->domainNegotiator->getActiveId();

      if (!empty($active_domain)) {
        $all_sitemap_variants = $this->sitemapManager
          ->getSitemapVariants('domain');

        if (array_key_exists($active_domain, $all_sitemap_variants)) {
          $variant = $active_domain;
        }
      }
    }

    return parent::getSitemap($request, $variant);
  }

}
